| Title: | Auxiliary Data Package for Our Main Package 'dartR' |
|---|---|
| Description: | Data package for 'dartR'. Provides data sets to run examples in 'dartR'. This was necessary due to the size limit imposed by 'CRAN'. The data in 'dartR.data' is needed to run the examples provided in the 'dartR' functions. All available data sets are either based on actual data (but reduced in size) and/or simulated data sets to allow the fast execution of examples and demonstration of the functions. |
| Authors: | Bernd Gruber [aut, cre], Arthur Georges [aut], Jose L. Mijangos [aut], Carlo Pacioni [aut], Oliver Berry [ctb] |
| Maintainer: | Bernd Gruber <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.2.2 |
| Built: | 2026-05-22 18:52:16 UTC |
| Source: | https://github.com/green-striped-gecko/dartr.data |
This a test data set to test the validity of functions within dartR and is based on a DArT SNP data set of simulated bandicoots across Australia. It contains 96 individuals and 1000 SNPs.
bandicoot.glbandicoot.gl
genlight object
Bernd Gruber (bugs? Post to https://groups.google.com/d/forum/dartr
Genetic data from EYR collected in VIC, Australia by researchers at Monash University. The data comes in the form of a genlight object ready to be used by dartR. The file contains data for 782 individuals from 4 populations and 1,000 binary SNPs. The dataset contains a mix of autosomal and sex-linked loci.
EYREYR
genlight object
Custodian: Diana Robledo-Ruiz – Post to https://groups.google.com/d/forum/dartr
Robledo-Ruiz et al. (2023) Easy-to-use R functions to separate reduced-representation genomic datasets into sex-linked and autosomal loci, and conduct sex assignment. Mol. Ecol. Res. (doi:10.1111/1755-0998.13844)
Genetic data from LBP collected in VIC, Australia by researchers at Monash University. The data comes in the form of a genlight object ready to be used by dartR. The file contains data for 376 individuals from 2 populations and 1,000 binary SNPs. The dataset contains a mix of autosomal and sex-linked loci.
LBPLBP
genlight object
Custodian: Diana Robledo-Ruiz – Post to https://groups.google.com/d/forum/dartr
Robledo-Ruiz et al. (2023) Easy-to-use R functions to separate reduced-representation genomic datasets into sex-linked and autosomal loci, and conduct sex assignment. Mol. Ecol. Res. doi:10.1111/1755-0998.13844
Check ?read.genetable in pacakge PopGenReport for details on the format.
csv
Bernd Gruber (bugs? Post to https://groups.google.com/d/forum/dartr
## Not run: library(PopGenReport) fp <- file.path(system.file( package="dartR.data"),"extdata/platy.csv") read.csv(fp) platy <- read.genetable(fp, ind=1, pop=2, lat=3, long=4, other.min=5, other.max=6, oneColPerAll=FALSE, sep='/') platy.gl <- gi2gl(platy, parallel=FALSE) df.loc <- data.frame(RepAvg = runif(nLoc(platy.gl)), CallRate = 1) platy.gl@other$loc.metrics <- df.loc gl.report.reproducibility(platy.gl) ## End(Not run)## Not run: library(PopGenReport) fp <- file.path(system.file( package="dartR.data"),"extdata/platy.csv") read.csv(fp) platy <- read.genetable(fp, ind=1, pop=2, lat=3, long=4, other.min=5, other.max=6, oneColPerAll=FALSE, sep='/') platy.gl <- gi2gl(platy, parallel=FALSE) df.loc <- data.frame(RepAvg = runif(nLoc(platy.gl)), CallRate = 1) platy.gl@other$loc.metrics <- df.loc gl.report.reproducibility(platy.gl) ## End(Not run)
This is a test data set on platypus with 81 individuals, 3 populations and 1,000 binary SNPs.
platypus.glplatypus.gl
genlight object
Luis Mijangos (bugs? Post to https://groups.google.com/d/forum/dartr
This a test data set to run a landscape genetics example. It contains 10 populations of 30 individuals each and each individual has 300 loci. There are no covariates for individuals or loci.
possums.glpossums.gl
genlight object
Bernd Gruber (bugs? Post to https://groups.google.com/d/forum/dartr
Metadata file. Can be integrated via the dart2genlight function.
csv
Custodian: Arthur Georges (bugs? Post to https://groups.google.com/d/forum/dartr
This test data set is provided to show a typical recode file format.
csv
Custodian: Arthur Georges (bugs? Post to https://groups.google.com/d/forum/dartr
This test data set is provided to show a typical DArT file format. Can be used to create a genlight object using the read.dart function.
csv
Custodian: Arthur Georges (bugs? Post to https://groups.google.com/d/forum/dartr
This is a test data set on turtles. 250 individuals, 255 loci in >30 populations.
testset.gltestset.gl
genlight object
Custodian: Arthur Georges (bugs? Post to https://groups.google.com/d/forum/dartr
This is a test data set on turtles. 218 individuals, 255 loci in >30 populations.
testset.gstestset.gs
genlight object
Custodian: Arthur Georges (bugs? Post to https://groups.google.com/d/forum/dartr
Genetic data from YTH collected in VIC, Australia by researchers at Monash University. The data comes in the form of a genlight object ready to be used by dartR. The file contains data for 641 individuals from 8 populations and 1,000 binary SNPs. The dataset contains a mix of autosomal and sex-linked loci.
YTHYTH
genlight object
Custodian: Diana Robledo-Ruiz – Post to https://groups.google.com/d/forum/dartr
Robledo-Ruiz et al. (2023) Easy-to-use R functions to separate reduced-representation genomic datasets into sex-linked and autosomal loci, and conduct sex assignment. Mol. Ecol. Res. (doi:10.1111/1755-0998.13844)
dartR.data Imports data for examples in dartR.base
zzzzzz
An object of class NULL of length 0.